.. _distribution_collection:

Collection
==========

.. currentmodule:: chaospy

Unbound distributions
---------------------

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   Cauchy
   DoubleGamma
   DoubleWeibull
   GeneralizedExtreme
   HyperbolicSecant
   Laplace
   LogGamma
   Logistic
   Normal
   PowerNormal
   StudentT

Partially bound distributions
-----------------------------

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   Alpha
   Burr
   Chi
   ChiSquared
   Maxwell
   Exponential
   ExponentialPower
   ExponentialWeibull
   F
   Fisk
   FoldedCauchy
   FoldedNormal
   Frechet
   Gamma
   GeneralizedExponential
   GeneralizedGamma
   GeneralizedHalfLogistic
   Gompertz
   InverseGamma
   Levy
   LogLaplace
   LogNormal
   LogWeibull
   Mielke
   Nakagami
   Pareto1
   Pareto2
   PowerLogNormal
   Wald
   Weibull
   WrappedCauchy

Bound distributions
-------------------

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   Anglit
   ArcSinus
   Beta
   Bradford
   FatigueLife
   PowerLaw
   Wigner
   PERT
   Kumaraswamy
   LogUniform
   Reciprocal
   Triangle
   TruncExponential
   TruncNormal
   TukeyLambda
   Uniform

.. _multivariate_distributions:

Multivariate distributions
--------------------------

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   MvLogNormal
   MvNormal
   MvStudentT

Discrete distributions
----------------------

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   Binomial
   DiscreteUniform

Copulas
-------

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   Clayton
   Gumbel
   Joe
   Nataf
   TCopula
